@@ -21,7 +21,7 @@ class init_anim:
         bpy.context.scene.frame_end = self.frame_duration+1
 
 class ref_frame:
-    def __init__(self, name, parent, init_anim):
+    def __init__(self, name, parent, anim):
         self.name = name
         self.parent = parent
         
@@ -33,8 +33,8 @@ class ref_frame:
         self.ob.empty_display_type = 'ARROWS'
         self.ob.rotation_mode = 'QUATERNION'
 
-        self.frames = init_anim.frames
-        self.scale = init_anim.scale
+        self.frames = anim.frames
+        self.scale = anim.scale
 
         
     def static_6DOF(self, quat, x, y, z):
@@ -77,6 +77,9 @@ class ref_frame:
 
 class dyn_obj:
     def __init__(self, obj, pa, euler_type, parent, anim):
+
+        self.frames = anim.frames
+        self.scale = anim.scale
         
         self.euler_pa = pa
         
@@ -95,9 +98,6 @@ class dyn_obj:
         self.body.static_6DOF(-self.quat, None, None, None)
 
         self.name = obj.name
-
-        self.frames = init_anim.frames
-        self.scale = init_anim.scale
         
     def apply_animation(self, x_list, y_list, z_list, quat_list):
         
